`awsmate` is a companion for your AWS developments in Python.
It provides you with helper code that facilitates the use of various AWS services.

## Installation

* Command line: `pip3 install awsmate`
* [PyPI page](https://pypi.org/project/awsmate/ "awsmate PyPI page")

## Documentation

The complete documentation is available at [ReadTheDocs](https://awsmate.readthedocs.io/ "awsmate documentation").

Documentation status: [![Documentation status](https://readthedocs.org/projects/awsmate/badge/?version=latest)](https://awsmate.readthedocs.io/en/latest/?badge=latest)

## Example application

An example application is available to demonstrate the main features of this library. It is documented [in this chapter](https://awsmate.readthedocs.io/en/latest/example_application.html).

## Issues

Should you encounter any bug or problem of any kind, please feel free to open an issue according to our [contribution guidelines](https://awsmate.readthedocs.io/en/latest/contributing.html).

Tests status: ![tests status](https://github.com/shlublu/awsmate/actions/workflows/tests.yaml/badge.svg?branch=master)

## License

This project is licensed under the EUROPEAN UNION PUBLIC LICENCE (EUPL) v. 1.2, which is compatible with the majority of open source licences.

* [View all translations](https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12 "Translations of the EUPL-1.2")
* [OSI Compatibility matrix](https://joinup.ec.europa.eu/collection/eupl/matrix-eupl-compatible-open-source-licences "Compatibility matrix of the EUPL-1.2")
